<?php

namespace Luticate\Utils;

class LuRoute {

    /**
     * @var callable
     */
    private $isAllowed = null;

    /**
     * @param $func callable
     */
    public function setPermissionFunction(callable $func)
    {
        $this->isAllowed = $func;
    }

    private function getOptions($url, $business, $method, $permissions = array())
    {
        $callback = $this->isAllowed;
        return [function() use($business, $method, $permissions, $callback)
        {
            if ($permissions == null) {
                $permissions = array();
            }
            else if (!is_array($permissions)) {
                $permissions = array($permissions);
            }
            if ($callback != null && !$callback($permissions)) {
                abort(401, "User does not have this permission");
            }
            $controller = new LuController();

            if (strpos($business, "\\") === false)
                $business = "App\\Http\\Business\\" . $business . "Business";

            return $controller->execute($business, $method);
        }];
    }

    public function get($url, $business, $method, $permissions = array())
    {
        global $app;
        return $app->get($url, $this->getOptions($url, $business, $method, $permissions));
    }

    public function post($url, $business, $method, $permissions = array())
    {
        global $app;
        return $app->post($url, $this->getOptions($url, $business, $method, $permissions));
    }

    public function put($url, $business, $method, $permissions = array())
    {
        global $app;
        return $app->put($url, $this->getOptions($url, $business, $method, $permissions));
    }

    public function delete($url, $business, $method, $permissions = array())
    {
        global $app;
        return $app->delete($url, $this->getOptions($url, $business, $method, $permissions));
    }
}